use strict;
use warnings;

package ExporterModule;

use Exporter 'import';
our @EXPORT_OK = qw(stuff);

sub stuff { }

1;
